@@ -65,6 +65,10 @@
 #ifndef CEPHES_MCONF_H
 #define CEPHES_MCONF_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "protos.h"
 
 /* Constant definitions for math error conditions
@@ -82,15 +86,6 @@
 #define EDOM		33
 #define ERANGE		34
 
-/* Long double complex numeral.  */
-/*
- * typedef struct
- * {
- * long double r;
- * long double i;
- * } cmplxl;
- */
-
 /* Type of computer arithmetic */
 
 /* UNKnown arithmetic, invokes coefficients given in
@@ -142,4 +137,8 @@ extern int merror;
 
 #define gamma Gamma
 
+#ifdef __cplusplus
+} // extern "C"
+#endif
+
 #endif				/* CEPHES_MCONF_H */
