@@ -6,11 +6,9 @@
 #ifndef __SCIPY_SPECIAL_CEPHES
 #define __SCIPY_SPECIAL_CEPHES
 
-/* Complex numeral.  */
-typedef struct {
-    double r;
-    double i;
-} cmplx;
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 extern double j1(double x);
 extern double y1(double x);
@@ -20,4 +18,8 @@ extern int mtherr(char *name, int code);
 extern double polevl(double x, double *P, int N);
 extern double p1evl(double x, double *P, int N);
 
+#ifdef __cplusplus
+} // extern "C"
+#endif
+
 #endif
