@@ -23,6 +23,7 @@ from datetime import datetime
 from lsl import astro
 from lsl.reader.base import FrameTimestamp
 from lsl.writer.fitsidi import WriterBase
+from lsl.common.color import colorfy
 
 from lsl.misc import telemetry
 telemetry.track_module()
@@ -120,14 +121,9 @@ try:
                 
         def __init__(self, filename, ref_time=0.0, verbose=False, memmap=None, overwrite=False):
             """
-            Initialize a new FITS IDI object using a filename and a reference time 
-            given in seconds since the UNIX 1970 ephem, a python datetime object, or a 
+            Initialize a new Measurment Set object using a filename and a reference time
+            given in seconds since the UNIX 1970 ephem, a python datetime object, or a
             string in the format of 'YYYY-MM-DDTHH:MM:SS'.
-            
-            .. versionchanged:: 1.1.2
-                Added the 'memmap' and 'overwrite' keywords to control if the file
-                is memory mapped and whether or not to overwrite an existing file, 
-                respectively.
             """
             
             # File-specific information
@@ -145,11 +141,6 @@ try:
             """
             Given a station and an array of stands, set the relevant common observation
             parameters and add entries to the self.array list.
-            
-            .. versionchanged:: 0.4.0
-                Switched over to passing in Antenna instances generated by the
-                :mod:`lsl.common.stations` module instead of a list of stand ID
-                numbers.
             """
             
             # Update the observatory-specific information
@@ -193,16 +184,6 @@ try:
             """
             Create a UVData object to store a collection of visibilities for the
             specified TAI MJD time.
-            
-            .. versionchanged:: 0.4.0
-                Switched over to passing in Antenna instances generated by the
-                :mod:`lsl.common.stations` module instead of a list of stand ID
-                as part of the baselines.
-                
-            .. versionchanged:: 1.1.0
-                Added a new 'source' keyword to set the phase center for the data.
-                This can either by 'z' for zenith or a ephem.Body instances for a
-                point on the sky.
             """
             
             if type(pol) == str:
@@ -211,7 +192,7 @@ try:
                 numericPol = pol
                 
             if isinstance(obsTime, FrameTimestamp):
-                obsTime = astro.unix_to_taimjd(obsTime.unix)
+                obsTime = obsTime.tai_mjd
             elif isinstance(obsTime, AstroTime):
                 obsTime = obsTime.tai.mjd
                 
@@ -219,7 +200,7 @@ try:
             
         def write(self):
             """
-            Fill in the FITS-IDI file will all of the tables in the 
+            Fill in the Measurement Set will all of the tables in the
             correct order.
             """
             
@@ -543,7 +524,7 @@ try:
                             equPo = astro.equ_posn(dataSet.source.a_ra*180/numpy.pi, dataSet.source.a_dec*180/numpy.pi)
                             
                         # J2000 zenith equatorial coordinates
-                        posList.append( [equPo.ra*numpy.pi/180, equPo.dec*numpy.pi/180] )
+                        posList.append( [[equPo.ra*numpy.pi/180, equPo.dec*numpy.pi/180],] )
                         
                         # name
                         nameList.append(name)
@@ -553,12 +534,12 @@ try:
             # Save these for later since we might need them
             self._sourceTable = nameList
             
-            col1  = tableutil.makearrcoldesc('DIRECTION', 0.0, 1, 
+            col1  = tableutil.makearrcoldesc('DIRECTION', 0.0, 2, 
                                              comment='Direction (e.g. RA, DEC).', 
                                              keywords={'QuantumUnits':['rad','rad'], 
                                                        'MEASINFO':{'type':'direction', 'Ref':'J2000'}
                                                        })
-            col2  = tableutil.makearrcoldesc('PROPER_MOTION', 0.0, 1, 
+            col2  = tableutil.makearrcoldesc('PROPER_MOTION', 0.0, 2, 
                                              comment='Proper motion', 
                                              keywords={'QuantumUnits':['rad/s',]})
             col3  = tableutil.makescacoldesc('CALIBRATION_GROUP', 0, 
@@ -601,8 +582,8 @@ try:
             tb = table("%s/SOURCE" % self.basename, desc, nrow=nSource, ack=False)
             
             for i in range(nSource):
-                tb.putcell('DIRECTION', i, posList[i])
-                tb.putcell('PROPER_MOTION', i, [0.0, 0.0])
+                tb.putcell('DIRECTION', i, numpy.array(posList[i]))
+                tb.putcell('PROPER_MOTION', i, numpy.array([[0.0, 0.0],]))
                 tb.putcell('CALIBRATION_GROUP', i, 0)
                 tb.putcell('CODE', i, 'none')
                 tb.putcell('INTERVAL', i, 0.0)
@@ -620,17 +601,17 @@ try:
             
             # Field
             
-            col1 = tableutil.makearrcoldesc('DELAY_DIR', 0.0, 1, 
+            col1 = tableutil.makearrcoldesc('DELAY_DIR', 0.0, 2, 
                                             comment='Direction of delay center (e.g. RA, DEC)as polynomial in time.', 
                                             keywords={'QuantumUnits':['rad','rad'], 
                                                       'MEASINFO':{'type':'direction', 'Ref':'J2000'}
                                                       })
-            col2 = tableutil.makearrcoldesc('PHASE_DIR', 0.0, 1, 
+            col2 = tableutil.makearrcoldesc('PHASE_DIR', 0.0, 2, 
                                             comment='Direction of phase center (e.g. RA, DEC).', 
                                             keywords={'QuantumUnits':['rad','rad'], 
                                                       'MEASINFO':{'type':'direction', 'Ref':'J2000'}
                                                       })
-            col3 = tableutil.makearrcoldesc('REFERENCE_DIR', 0.0, 1, 
+            col3 = tableutil.makearrcoldesc('REFERENCE_DIR', 0.0, 2, 
                                             comment='Direction of REFERENCE center (e.g. RA, DEC).as polynomial in time.', 
                                             keywords={'QuantumUnits':['rad','rad'], 
                                                       'MEASINFO':{'type':'direction', 'Ref':'J2000'}
@@ -685,7 +666,7 @@ try:
                                                        'MEASINFO':{'type':'frequency', 
                                                                    'VarRefCol':'MEAS_FREQ_REF', 
                                                                    'TabRefTypes':['REST','LSRK','LSRD','BARY','GEO','TOPO','GALACTO','LGROUP','CMB','Undefined'],
-                                                                   'TabRefCodes':[0,1,2,3,4,5,6,7,8,64]}
+                                                                   'TabRefCodes':numpy.array([0,1,2,3,4,5,6,7,8,64], dtype=numpy.uint32)}
                                                        })
             col3  = tableutil.makescacoldesc('REF_FREQUENCY', self.refVal, 
                                              comment='The reference frequency', 
@@ -693,7 +674,7 @@ try:
                                                        'MEASINFO':{'type':'frequency', 
                                                                    'VarRefCol':'MEAS_FREQ_REF', 
                                                                    'TabRefTypes':['REST','LSRK','LSRD','BARY','GEO','TOPO','GALACTO','LGROUP','CMB','Undefined'],
-                                                                   'TabRefCodes':[0,1,2,3,4,5,6,7,8,64]}
+                                                                   'TabRefCodes':numpy.array([0,1,2,3,4,5,6,7,8,64], dtype=numpy.uint32)}
                                                        })
             col4  = tableutil.makearrcoldesc('CHAN_WIDTH', 0.0, 1, 
                                              comment='Channel width for each channel', 
@@ -836,10 +817,15 @@ try:
             for dataSet in self.data:
                 # Sort the data by packed baseline
                 try:
-                    order
+                    if len(dataSet.visibilities) != len(order):
+                        raise NameError
                 except NameError:
                     order = dataSet.argsort(mapper=mapper, shift=16)
-                    
+                    try:
+                        del baselineMapped
+                    except NameError:
+                        pass
+                        
                 # Deal with defininig the values of the new data set
                 if dataSet.pol == self.stokes[0]:
                     ## Figure out the new date/time for the observation
@@ -909,6 +895,8 @@ try:
                      
                     ### Zero out the visibility data
                     try:
+                        if matrix.shape[0] != len(order):
+                            raise NameError
                         matrix.shape = (len(order), self.nStokes, nBand*self.nChan)
                         matrix *= 0.0
                     except NameError:
@@ -1129,7 +1117,7 @@ try:
             
 except ImportError:
     import warnings
-    warnings.warn('Cannot import casacore.tables, MS support disabled', ImportWarning)
+    warnings.warn(colorfy('{{%yellow Cannot import casacore.tables, MS support disabled}}'), RuntimeWarning)
     
     class Ms(WriterBase):
         """
@@ -1141,14 +1129,9 @@ except ImportError:
         
         def __init__(self, filename, ref_time=0.0, verbose=False, memmap=None, overwrite=False):
             """
-            Initialize a new FITS IDI object using a filename and a reference time 
+            Initialize a new Measurement Set object using a filename and a reference time
             given in seconds since the UNIX 1970 ephem, a python datetime object, or a 
             string in the format of 'YYYY-MM-DDTHH:MM:SS'.
-            
-            .. versionchanged:: 1.1.2
-                Added the 'memmap' and 'overwrite' keywords to control if the file
-                is memory mapped and whether or not to overwrite an existing file, 
-                respectively.
             """
             
             raise RuntimeError("Cannot import casacore.tables, MS support disabled")
