@@ -30,6 +30,7 @@ from lsl.writer.fitsidi import Idi, NUMERIC_STOKES
 from lsl.sim import vis
 from lsl.common.stations import lwa1, parse_ssmif
 from lsl.correlator import uvutils
+import lsl.testing
 
 run_ms_tests = False
 try:
@@ -49,7 +50,7 @@ except ImportError:
     pass
 
 
-__version__  = "0.1"
+__version__  = "0.2"
 __author__    = "Jayce Dowell"
 
 
@@ -63,8 +64,6 @@ class imaging_tests(unittest.TestCase):
     """A unittest.TestCase collection of unit tests for the lsl.imaging
     modules."""
     
-    testPath = None
-
     def setUp(self):
         """Turn off all numpy warnings and create the temporary file directory."""
 
@@ -92,6 +91,8 @@ class imaging_tests(unittest.TestCase):
         # Error checking
         self.assertRaises(IndexError, idi.get_data_set, 2)
         
+        idi.close()
+        
         # 'with' statement support
         with utils.CorrelatedDataIDI(idiFile) as idi:
             ## Basic functions (just to see that they run)
@@ -107,6 +108,8 @@ class imaging_tests(unittest.TestCase):
             i += 1
         self.assertEqual(i, 1)
         
+        idi.close()
+        
         # both at the same time
         with utils.CorrelatedDataIDI(idiFile) as idi:
             i = 0
@@ -115,7 +118,7 @@ class imaging_tests(unittest.TestCase):
                 i += 1
             self.assertEqual(i, 1)
             
-    def __initData(self):
+    def _init_data(self):
         """Private function to generate a random set of data for writing a UVFITS
         file.  The data is returned as a dictionary with keys:
          * freq - frequency array in Hz
@@ -142,7 +145,7 @@ class imaging_tests(unittest.TestCase):
         """Test the utils.CorrelatedDataIDI class on a file with multiple IFs."""
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         # Filename and time
         testTime, testFile = time.time(), os.path.join('idi-test-MultiIF.fits')
@@ -156,17 +159,18 @@ class imaging_tests(unittest.TestCase):
         fits.add_data_set(astro.utcjd_to_taimjd(astro.unix_to_utcjd(testTime)), 6.0, data['bl'], 
                           numpy.concatenate([data['vis'], 10*data['vis']], axis=1))
         fits.write()
+        fits.close()
         
         # Open the FITS IDI file
         idi = utils.CorrelatedData(testFile)
         self.assertEqual(idi.freq.size, 2*data['freq'].size)
         ds = idi.get_data_set(1, include_auto=True)
         
-        for i in range(len(data['bl'])):
-            for j in range(data['freq'].size):
-                self.assertAlmostEqual(ds.XX.data[i,j], data['vis'][i,j], 6)
-                self.assertAlmostEqual(ds.XX.data[i,j+data['freq'].size], 10*data['vis'][i,j], 6)
-                
+        numpy.testing.assert_allclose(ds.XX.data[:,:data['freq'].size], data['vis'])
+        numpy.testing.assert_allclose(ds.XX.data[:,data['freq'].size:], 10*data['vis'])
+        
+        idi.close()
+        
     def test_CorrelatedDataIDI_Alt(self):
         """Test the utils.CorrelatedDataIDI class on a file with an unusual telescope."""
         
@@ -189,6 +193,8 @@ class imaging_tests(unittest.TestCase):
         # Error checking
         self.assertRaises(IndexError, idi.get_data_set, 2)
         
+        idi.close()
+        
     def test_CorrelatedDataIDI_AltArrayGeometry(self):
         """Test the utils.CorrelatedDataIDI class on determing array geometry."""
         
@@ -225,6 +231,9 @@ class imaging_tests(unittest.TestCase):
             self.assertAlmostEqual(a1.stand.y, a2.stand.y, 2)
             self.assertAlmostEqual(a1.stand.z, a2.stand.z, 2)
             
+        idi1.close()
+        idi2.close()
+        
     def test_CorrelatedDataUV(self):
         """Test the utils.CorrelatedDataUV class."""
         
@@ -247,6 +256,8 @@ class imaging_tests(unittest.TestCase):
         # Error checking
         self.assertRaises(IndexError, uv.get_data_set, 2)
         
+        uv.close()
+        
     @unittest.skipUnless(run_ms_tests, "requires the 'casacore' module")
     def test_CorrelatedDataMS(self):
         """Test the utils.CorrelatedDataMS class."""
@@ -254,7 +265,7 @@ class imaging_tests(unittest.TestCase):
         testTime, testFile = time.time(), os.path.join(self.testPath, 'ms-test-W.ms')
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         # Start the table
         tbl = Ms(testFile, ref_time=testTime)
@@ -275,12 +286,14 @@ class imaging_tests(unittest.TestCase):
         # Error checking
         self.assertRaises(IndexError, ms.get_data_set, 2)
         
+        tbl.close()
+        
     @unittest.skipUnless(run_ms_tests, "requires the 'casacore' module")
     def test_CorrelatedDataMS_SingleIF(self):
         """Test the utils.CorrelatedDataMS class on a file with a single IF."""
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         # Filename and time
         testTime, testFile = time.time(), os.path.join(self.testPath, 'ms-test-SingleIF.ms')
@@ -292,22 +305,23 @@ class imaging_tests(unittest.TestCase):
         fits.set_geometry(data['site'], data['antennas'])
         fits.add_data_set(astro.utcjd_to_taimjd(astro.unix_to_utcjd(testTime)), 6.0, data['bl'], data['vis'])
         fits.write()
+        fits.close()
         
         # Open the measurement set
         ms = utils.CorrelatedDataMS(testFile)
         self.assertEqual(ms.freq.size, data['freq'].size)
         ds = ms.get_data_set(1, include_auto=True)
         
-        for i in range(len(data['bl'])):
-            for j in range(data['freq'].size):
-                self.assertAlmostEqual(ds.XX.data[i,j], data['vis'][i,j], 6)
-                
+        numpy.testing.assert_allclose(ds.XX.data, data['vis'])
+        
+        ms.close()
+        
     @unittest.skipUnless(run_ms_tests, "requires the 'casacore' module")
     def test_CorrelatedDataMS_MultiIF(self):
         """Test the utils.CorrelatedDataMS class on a file with multiple IFs."""
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         # Filename and time
         testTime, testFile = time.time(), os.path.join(self.testPath, 'ms-test-MultiIF.ms')
@@ -321,23 +335,24 @@ class imaging_tests(unittest.TestCase):
         fits.add_data_set(astro.utcjd_to_taimjd(astro.unix_to_utcjd(testTime)), 6.0, data['bl'], 
                           numpy.concatenate([data['vis'], 10*data['vis']], axis=1))
         fits.write()
+        fits.close()
         
         # Open the measurement set
         ms = utils.CorrelatedDataMS(testFile)
         self.assertEqual(ms.freq.size, 2*data['freq'].size)
         ds = ms.get_data_set(1, include_auto=True)
         
-        for i in range(len(data['bl'])):
-            for j in range(data['freq'].size):
-                self.assertAlmostEqual(ds.XX.data[i,j], data['vis'][i,j], 6)
-                self.assertAlmostEqual(ds.XX.data[i,j+data['freq'].size], 10*data['vis'][i,j], 6)
-                
+        numpy.testing.assert_allclose(ds.XX.data[:,:data['freq'].size], data['vis'])
+        numpy.testing.assert_allclose(ds.XX.data[:,data['freq'].size:], 10*data['vis'])
+        
+        ms.close()
+        
     @unittest.skipUnless(run_ms_tests, "requires the 'casacore' module")
     def test_CorrelatedDataMS_compressed(self):
         """Test the utils.CorrelatedDataMS class on a compressed file."""
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         # Filename and time
         testTime, testFile = time.time(), os.path.join(self.testPath, 'ms-test-MultiIF.ms')
@@ -351,6 +366,7 @@ class imaging_tests(unittest.TestCase):
         fits.add_data_set(astro.utcjd_to_taimjd(astro.unix_to_utcjd(testTime)), 6.0, data['bl'], 
                           numpy.concatenate([data['vis'], 10*data['vis']], axis=1))
         fits.write()
+        fits.close()
         
         # Compress
         compressedFile = os.path.splitext(testFile)[0]+'.tar.gz'
@@ -362,400 +378,209 @@ class imaging_tests(unittest.TestCase):
         self.assertEqual(ms.freq.size, 2*data['freq'].size)
         ds = ms.get_data_set(1, include_auto=True)
         
-        for i in range(len(data['bl'])):
-            for j in range(data['freq'].size):
-                self.assertAlmostEqual(ds.XX.data[i,j], data['vis'][i,j], 6)
-                self.assertAlmostEqual(ds.XX.data[i,j+data['freq'].size], 10*data['vis'][i,j], 6)
-                
+        numpy.testing.assert_allclose(ds.XX.data[:,:data['freq'].size], data['vis'])
+        numpy.testing.assert_allclose(ds.XX.data[:,data['freq'].size:], 10*data['vis'])
+        
+        ms.close()
+        
     def test_sort(self):
         """Test the utils.sort function."""
         
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiFile)
-        
-        # Get some data to sort
-        ds = idi.get_data_set(1, sort=False)
-        
-        # Sort
-        dss = ds.copy()
-        dss.sort()
-        for pol in ds.pols:
-            p0 = getattr(ds,  pol)
-            p1 = getattr(dss, pol)
-            self.assertEqual(p0.nbaseline, p1.nbaseline)
-            
-    def test_sort_alt(self):
-        """Test the utils.sort function - alternate FITS IDI file."""
-        
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiAltFile)
-        
-        # Get some data to sort
-        ds = idi.get_data_set(1, sort=False)
-        
-        # Sort
-        dss = ds.copy()
-        dss.sort()
-        for pol in ds.pols:
-            p0 = getattr(ds,  pol)
-            p1 = getattr(dss, pol)
-            self.assertEqual(p0.nbaseline, p1.nbaseline)
-            
-    def test_sort_uvfits(self):
-        """Test the utils.sort function - UVFITS file."""
-        
-        # Open the FITS IDI file
-        uv = utils.CorrelatedData(uvFile)
-        
-        # Get some data to sort
-        ds = uv.get_data_set(1, sort=False)
-        
-        # Sort
-        dss = ds.copy()
-        dss.sort()
-        for pol in ds.pols:
-            p0 = getattr(ds,  pol)
-            p1 = getattr(dss, pol)
-            self.assertEqual(p0.nbaseline, p1.nbaseline)
-            
+        for filename,type in zip((idiFile, idiAltFile, uvFile), ('FITS-IDI', 'Alt. FITS-IDI', 'UVFITS')):
+            with self.subTest(filetype=type):
+                # Open the file
+                idi = utils.CorrelatedData(filename)
+                
+                # Get some data to sort
+                ds = idi.get_data_set(1, sort=False)
+                
+                # Sort
+                dss = ds.copy()
+                dss.sort()
+                for pol in ds.pols:
+                    p0 = getattr(ds,  pol)
+                    p1 = getattr(dss, pol)
+                    self.assertEqual(p0.nbaseline, p1.nbaseline)
+                    
     def test_prune(self):
         """Test the utils.get_uv_range function."""
         
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiFile)
-        
-        # Get some data to sort
-        ds = idi.get_data_set(1)
-        
-        # Prune
-        dsp1 = ds.get_uv_range(min_uv=10)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p1 = getattr(dsp1, pol)
-            self.assertTrue(p1.nbaseline < p0.nbaseline)
-            
-        # Auto-prune
-        dsp2 = idi.get_data_set(1, min_uv=10)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p2 = getattr(dsp2, pol)
-            self.assertTrue(p2.nbaseline < p0.nbaseline)
-            
-        # Auto-prune that should result in no baselines
-        dsp3 = idi.get_data_set(1, min_uv=100)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p3 = getattr(dsp3, pol)
-            self.assertEqual(p3.nbaseline, 0)
-            
+        for filename,type in zip((idiFile, idiAltFile, uvFile), ('FITS-IDI', 'Alt. FITS-IDI', 'UVFITS')):
+            with self.subTest(filetype=type):
+                # Open the file
+                idi = utils.CorrelatedData(filename)
+                
+                # Get some data to sort
+                ds = idi.get_data_set(1)
+                
+                # Prune
+                dsp1 = ds.get_uv_range(min_uv=10)
+                for pol in ds.pols:
+                    p0 = getattr(ds,   pol)
+                    p1 = getattr(dsp1, pol)
+                    self.assertTrue(p1.nbaseline < p0.nbaseline)
+                    
+                # Auto-prune
+                dsp2 = idi.get_data_set(1, min_uv=10)
+                for pol in ds.pols:
+                    p0 = getattr(ds,   pol)
+                    p2 = getattr(dsp2, pol)
+                    self.assertTrue(p2.nbaseline < p0.nbaseline)
+                    
+                # Auto-prune that should result in no baselines
+                dsp3 = idi.get_data_set(1, min_uv=100)
+                for pol in ds.pols:
+                    p0 = getattr(ds,   pol)
+                    p3 = getattr(dsp3, pol)
+                    self.assertEqual(p3.nbaseline, 0)
+                    
+                idi.close()
+                
     def test_subset(self):
         """Test the utils.get_antenna_subset function."""
         
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiFile)
-        
-        # Get some data to sort
-        ds = idi.get_data_set(1)
-        
-        # Indicies
-        ## Include
-        dss1 = ds.get_antenna_subset(include=(0,1,2), indicies=True)
-        self.assertEqual(len(dss1.baselines), 3)
-        for a1,a2 in dss1.baselines:
-            self.assertTrue(a1 in (0,1,2))
-            self.assertTrue(a2 in (0,1,2))
-            
-        ## Exclude
-        dss2 = ds.get_antenna_subset(exclude=(4,), indicies=True)
-        self.assertEqual(len(dss2.baselines), 6)
-        for a1,a2 in dss2.baselines:
-            self.assertTrue(a1 != 4)
-            self.assertTrue(a2 != 4)
-            
-        # Stand numbers
-        ## Include
-        dss1 = ds.get_antenna_subset(include=(151,222,150), indicies=False)
-        self.assertEqual(len(dss1.baselines), 3)
-        for a1,a2 in dss1.baselines:
-            self.assertTrue(a1 in [idi.stands.index(s) for s in (151,222,150)])
-            self.assertTrue(a2 in [idi.stands.index(s) for s in (151,222,150)])
-            
-        ## Exclude
-        dss2 = ds.get_antenna_subset(exclude=(173,), indicies=False)
-        self.assertEqual(len(dss2.baselines), 6)
-        for a1,a2 in dss2.baselines:
-            self.assertTrue(a1 != idi.stands.index(173))
-            self.assertTrue(a2 != idi.stands.index(173))
-            
-    def test_prune_alt(self):
-        """Test the utils.get_uv_range function - alternate FITS IDI file."""
-        
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiAltFile)
-        
-        # Get some data to sort
-        ds = idi.get_data_set(1)
-        
-        # Prune
-        dsp1 = ds.get_uv_range(min_uv=10)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p1 = getattr(dsp1, pol)
-            self.assertTrue(p1.nbaseline < p0.nbaseline)
-            
-        # Auto-prune
-        dsp2 = idi.get_data_set(1, min_uv=10)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p2 = getattr(dsp2, pol)
-            self.assertTrue(p2.nbaseline < p0.nbaseline)
-            
-        # Auto-prune that should result in no baselines
-        dsp3 = idi.get_data_set(1, min_uv=100)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p3 = getattr(dsp3, pol)
-            self.assertEqual(p3.nbaseline, 0)
-            
-    def test_prune_uvfits(self):
-        """Test the utils.get_uv_range function - UVFITS file."""
-        
-        # Open the FITS IDI file
-        uv = utils.CorrelatedData(uvFile)
-        
-        # Get some data to sort
-        ds = uv.get_data_set(1)
-        
-        # Prune
-        dsp1 = ds.get_uv_range(min_uv=10)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p1 = getattr(dsp1, pol)
-            self.assertTrue(p1.nbaseline < p0.nbaseline)
-            
-        # Auto-prune
-        dsp2 = uv.get_data_set(1, min_uv=10)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p2 = getattr(dsp2, pol)
-            self.assertTrue(p2.nbaseline < p0.nbaseline)
-            
-        # Auto-prune that should result in no baselines
-        dsp3 = uv.get_data_set(1, min_uv=100)
-        for pol in ds.pols:
-            p0 = getattr(ds,   pol)
-            p3 = getattr(dsp3, pol)
-            self.assertEqual(p3.nbaseline, 0)
-            
+        for filename,type in zip((idiFile, idiAltFile, uvFile), ('FITS-IDI', 'Alt. FITS-IDI', 'UVFITS')):
+            with self.subTest(filetype=type):
+                # Open the file
+                idi = utils.CorrelatedData(filename)
+                
+                # Get some data to sort
+                ds = idi.get_data_set(1)
+                
+                # Indicies
+                ## Include
+                dss1 = ds.get_antenna_subset(include=(0,1,2), indicies=True)
+                self.assertEqual(len(dss1.baselines), 3)
+                for a1,a2 in dss1.baselines:
+                    self.assertTrue(a1 in (0,1,2))
+                    self.assertTrue(a2 in (0,1,2))
+                    
+                ## Exclude
+                dss2 = ds.get_antenna_subset(exclude=(4,), indicies=True)
+                self.assertEqual(len(dss2.baselines), 6)
+                for a1,a2 in dss2.baselines:
+                    self.assertTrue(a1 != 4)
+                    self.assertTrue(a2 != 4)
+                    
+                # Stand numbers
+                ## Include
+                dss1 = ds.get_antenna_subset(include=(151,222,150), indicies=False)
+                self.assertEqual(len(dss1.baselines), 3)
+                for a1,a2 in dss1.baselines:
+                    self.assertTrue(a1 in [idi.stands.index(s) for s in (151,222,150)])
+                    self.assertTrue(a2 in [idi.stands.index(s) for s in (151,222,150)])
+                    
+                ## Exclude
+                dss2 = ds.get_antenna_subset(exclude=(173,), indicies=False)
+                self.assertEqual(len(dss2.baselines), 6)
+                for a1,a2 in dss2.baselines:
+                    self.assertTrue(a1 != idi.stands.index(173))
+                    self.assertTrue(a2 != idi.stands.index(173))
+                    
+                idi.close()
+                
     def test_rephase(self):
         """Test the utils.rephase_data function."""
         
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiFile)
-        
-        # Get the AntennaArray instance
-        aa = idi.get_antennaarray()
-        
-        # Get some data to sort
-        ds = idi.get_data_set(1)
-        orig_bls = ds.baselines
-        orig_dat = ds.XX.data.copy()
-        orig_pc  = ds.phase_center
-        
-        # Rephase #1
-        ds.rephase(new_phase_center=vis.SOURCES['Sun'])
-        for i in range(ds.nbaseline):
-            self.assertEqual(orig_bls[i][0], ds.baselines[i][0])
-            self.assertEqual(orig_bls[i][1], ds.baselines[i][1])
-            
-        # Rephase #2
-        ds.rephase(new_phase_center=orig_pc)
-        for i in range(ds.nbaseline):
-            self.assertEqual(orig_bls[i][0], ds.baselines[i][0])
-            self.assertEqual(orig_bls[i][1], ds.baselines[i][1])
-            
-            for j in range(ds.nchan):
-                self.assertAlmostEqual(orig_dat[i][j], ds.XX.data[i][j], 2)
+        for filename,type in zip((idiFile, idiAltFile, uvFile), ('FITS-IDI', 'Alt. FITS-IDI', 'UVFITS')):
+            with self.subTest(filetype=type):
+                # Open the file
+                idi = utils.CorrelatedData(filename)
                 
-        # Bad rephase
-        self.assertRaises(RuntimeError, ds.rephase, vis.SOURCES['vir'])
-        
-    def test_rephase_alt(self):
-        """Test the utils.rephase_data function - alternate FITS IDI file."""
-        
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiAltFile)
-        
-        # Get the AntennaArray instance
-        aa = idi.get_antennaarray()
-        
-        # Get some data to sort
-        ds = idi.get_data_set(1)
-        orig_bls = ds.baselines
-        orig_dat = ds.XX.data.copy()
-        orig_pc  = ds.phase_center
-        
-        # Rephase #1
-        ds.rephase(new_phase_center=vis.SOURCES['Sun'])
-        for i in range(ds.nbaseline):
-            self.assertEqual(orig_bls[i][0], ds.baselines[i][0])
-            self.assertEqual(orig_bls[i][1], ds.baselines[i][1])
-            
-        # Rephase #2
-        ds.rephase(new_phase_center=orig_pc)
-        for i in range(ds.nbaseline):
-            self.assertEqual(orig_bls[i][0], ds.baselines[i][0])
-            self.assertEqual(orig_bls[i][1], ds.baselines[i][1])
-            
-            for j in range(ds.nchan):
-                self.assertAlmostEqual(orig_dat[i][j], ds.XX.data[i][j], 2)
+                # Get the AntennaArray instance
+                aa = idi.get_antennaarray()
                 
-        # Bad rephase
-        self.assertRaises(RuntimeError, ds.rephase, vis.SOURCES['vir'])
-        
-    def test_rephase_uvfits(self):
-        """Test the utils.rephase_data function - UVFITS file."""
-        
-        # Open the UVFITS file
-        uv = utils.CorrelatedData(uvFile)
-        
-        # Get the AntennaArray instance
-        aa = uv.get_antennaarray()
-        
-        # Get some data to sort
-        ds = uv.get_data_set(1)
-        orig_bls = ds.baselines
-        orig_dat = ds.XX.data.copy()
-        orig_pc  = ds.phase_center
-        
-        # Rephase #1
-        ds.rephase(new_phase_center=vis.SOURCES['Sun'])
-        for i in range(ds.nbaseline):
-            self.assertEqual(orig_bls[i][0], ds.baselines[i][0])
-            self.assertEqual(orig_bls[i][1], ds.baselines[i][1])
-            
-        # Rephase #2
-        ds.rephase(new_phase_center=orig_pc)
-        for i in range(ds.nbaseline):
-            self.assertEqual(orig_bls[i][0], ds.baselines[i][0])
-            self.assertEqual(orig_bls[i][1], ds.baselines[i][1])
-            
-            for j in range(ds.nchan):
-                self.assertAlmostEqual(orig_dat[i][j], ds.XX.data[i][j], 2)
+                # Get some data to sort
+                ds = idi.get_data_set(1)
+                orig_bls = ds.baselines
+                orig_dat = ds.XX.data.copy()
+                orig_pc  = ds.phase_center
+                
+                # Rephase #1
+                ds.rephase(new_phase_center=vis.SOURCES['Sun'])
+                for i in range(ds.nbaseline):
+                    self.assertEqual(orig_bls[i][0], ds.baselines[i][0])
+                    self.assertEqual(orig_bls[i][1], ds.baselines[i][1])
+                    
+                # Rephase #2
+                ds.rephase(new_phase_center=orig_pc)
+                for i in range(ds.nbaseline):
+                    self.assertEqual(orig_bls[i][0], ds.baselines[i][0])
+                    self.assertEqual(orig_bls[i][1], ds.baselines[i][1])
+                    
+                    for j in range(ds.nchan):
+                        self.assertAlmostEqual(orig_dat[i][j], ds.XX.data[i][j], 2)
+                        
+                # Bad rephase
+                self.assertRaises(RuntimeError, ds.rephase, vis.SOURCES['vir'])
+                
+                idi.close()
                 
-        # Bad rephase
-        self.assertRaises(RuntimeError, ds.rephase, vis.SOURCES['vir'])
-        
     def test_gridding(self):
         """Test building a image from a visibility data set."""
         
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiFile)
-        
-        # Build the image
-        ds = idi.get_data_set(1)
-        junk = utils.build_gridded_image(ds, verbose=False)
+        for filename,type in zip((idiFile, idiAltFile, uvFile), ('FITS-IDI', 'Alt. FITS-IDI', 'UVFITS')):
+            with self.subTest(filetype=type):
+                # Open the file
+                idi = utils.CorrelatedData(filename)
+                
+                # Build the image
+                ds = idi.get_data_set(1)
+                junk = utils.build_gridded_image(ds, verbose=False)
 
-        # Error checking
-        self.assertRaises(RuntimeError, utils.build_gridded_image, ds, pol='XY')
-        
-        #
-        # VisibilityData test
-        #
-        
-        ds2 = VisibilityData()
-        ds2.append( ds )
-        junk = utils.build_gridded_image(ds, verbose=False)
-        
-    def test_gridding_alt(self):
-        """Test building a image from a visibility data set - alternate FITS IDI file."""
-        
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiAltFile)
-        
-        # Build the image
-        ds = idi.get_data_set(1)
-        junk = utils.build_gridded_image(ds, verbose=False)
-
-        # Error checking
-        self.assertRaises(RuntimeError, utils.build_gridded_image, ds, pol='XY')
-        
-    def test_gridding_uvfits(self):
-        """Test building a image from a visibility data set - UVFITS file."""
-        
-        # Open the UVFITS file
-        uv = utils.CorrelatedData(uvFile)
-        
-        # Build the image
-        ds = uv.get_data_set(1)
-        junk = utils.build_gridded_image(ds, verbose=False)
-        
-        # Error checking
-        self.assertRaises(RuntimeError, utils.build_gridded_image, ds, pol='XY')
-        
+                # Error checking
+                self.assertRaises(RuntimeError, utils.build_gridded_image, ds, pol='XY')
+                
+                #
+                # VisibilityData test
+                #
+                
+                ds2 = VisibilityData()
+                ds2.append( ds )
+                junk = utils.build_gridded_image(ds, verbose=False)
+                
+                idi.close()
+                
     def test_image_coordinates(self):
         """Test getting per-pixel image coordinates."""
         
-        # Open the UVFITS file
-        uv = utils.CorrelatedData(uvFile)
-        
-        # Build the image
-        ds = uv.get_data_set(1)
-        junk = utils.build_gridded_image(ds, verbose=False)
-        
-        radec = utils.get_image_radec(junk, uv.get_antennaarray())
-        azalt = utils.get_image_azalt(junk, uv.get_antennaarray())
+        for filename,type in zip((idiFile, idiAltFile, uvFile), ('FITS-IDI', 'Alt. FITS-IDI', 'UVFITS')):
+            with self.subTest(filetype=type):
+                uv = utils.CorrelatedData(filename)
+                
+                # Build the image
+                ds = uv.get_data_set(1)
+                junk = utils.build_gridded_image(ds, verbose=False)
+                
+                radec = utils.get_image_radec(junk, uv.get_antennaarray())
+                azalt = utils.get_image_azalt(junk, uv.get_antennaarray())
+                
+                uv.close()
         
     def test_selfcal(self):
         """Test running a simple self calibration."""
         
-        # Open the FITS IDI file
-        idi = utils.CorrelatedData(idiFile)
-        
-        # Go for it!
-        aa = idi.get_antennaarray()
-        ds = idi.get_data_set(1)
-        junk = selfcal.phase_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False, amplitude=True)
-        junk = selfcal.phase_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False)
-        junk = selfcal.delay_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False, amplitude=True)
-        junk = selfcal.delay_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False)
-        junk = selfcal.delay_and_phase(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False, amplitude=True)
-        junk = selfcal.delay_and_phase(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False)
-        
-        # Error checking
-        self.assertRaises(RuntimeError, selfcal.phase_only, aa, ds, ds, 173, 'YX', ref_ant=0  )
-        self.assertRaises(RuntimeError, selfcal.phase_only, aa, ds, ds, 173, 'YX', ref_ant=564)
-        
-    def test_selfcal_alt(self):
-        """Test running a simple self calibration - alternate FITS IDI file."""
-        
-        # Open the alternate FITS IDI file
-        idi = utils.CorrelatedData(idiAltFile)
-        
-        # Go for it!
-        aa = idi.get_antennaarray()
-        ds = idi.get_data_set(1)
-        junk = selfcal.phase_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False)
-        
-        # Error checking
-        self.assertRaises(RuntimeError, selfcal.phase_only, aa, ds, ds, 173, 'YX', ref_ant=0  )
-        self.assertRaises(RuntimeError, selfcal.phase_only, aa, ds, ds, 173, 'YX', ref_ant=564)
-        
-    def test_selfcal_uvfits(self):
-        """Test running a simple self calibration - UVFITS file."""
-        
-        # Open the alternate UVFITS file
-        uv = utils.CorrelatedData(uvFile)
-        
-        # Go for it!
-        aa = uv.get_antennaarray()
-        ds = uv.get_data_set(1)
-        junk = selfcal.phase_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False)
-        
-        # Error checking
-        self.assertRaises(RuntimeError, selfcal.phase_only, aa, ds, ds, 173, 'YX', ref_ant=0  )
-        self.assertRaises(RuntimeError, selfcal.phase_only, aa, ds, ds, 173, 'YX', ref_ant=564)
-        
+        for filename,type in zip((idiFile, idiAltFile, uvFile), ('FITS-IDI', 'Alt. FITS-IDI', 'UVFITS')):
+            with self.subTest(filetype=type):
+                # Open the file
+                idi = utils.CorrelatedData(idiFile)
+                
+                # Go for it!
+                aa = idi.get_antennaarray()
+                ds = idi.get_data_set(1)
+                junk = selfcal.phase_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False, amplitude=True)
+                junk = selfcal.phase_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False)
+                junk = selfcal.delay_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False, amplitude=True)
+                junk = selfcal.delay_only(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False)
+                junk = selfcal.delay_and_phase(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False, amplitude=True)
+                junk = selfcal.delay_and_phase(aa, ds, ds, 173, 'XX', max_iter=1, verbose=False)
+                
+                # Error checking
+                self.assertRaises(RuntimeError, selfcal.phase_only, aa, ds, ds, 173, 'YX', ref_ant=0  )
+                self.assertRaises(RuntimeError, selfcal.phase_only, aa, ds, ds, 173, 'YX', ref_ant=564)
+                
+                idi.close()
+                
     def test_background(self):
         """Test the background estimation"""
         
@@ -792,12 +617,13 @@ class imaging_tests(unittest.TestCase):
         # Build the data dictionary
         out = vis.build_sim_data(aa, vis.SOURCES, jd=2458962.16965)
         
-        # Build an image
-        img = utils.build_gridded_image(out)
-        
-        # CLEAN
-        deconv.clean(aa, out, img, max_iter=5, verbose=False, plot=run_plotting_tests)
-        
+        with lsl.testing.SilentVerbose():
+            # Build an image
+            img = utils.build_gridded_image(out)
+            
+            # CLEAN
+            deconv.clean(aa, out, img, max_iter=5, verbose=False, plot=run_plotting_tests)
+            
     def test_clean_sources(self):
         """Test CLEANing around specific sources"""
         
@@ -809,12 +635,13 @@ class imaging_tests(unittest.TestCase):
         # Build the data dictionary
         out = vis.build_sim_data(aa, vis.SOURCES, jd=2458962.16965)
         
-        # Build an image
-        img = utils.build_gridded_image(out)
-        
-        # CLEAN
-        deconv.clean_sources(aa, out, img, vis.SOURCES, max_iter=5, verbose=False, plot=run_plotting_tests)
-        
+        with lsl.testing.SilentVerbose():
+            # Build an image
+            img = utils.build_gridded_image(out)
+            
+            # CLEAN
+            deconv.clean_sources(aa, out, img, vis.SOURCES, max_iter=5, verbose=False, plot=run_plotting_tests)
+            
     def test_clean_leastsq(self):
         """Test CLEANing using least squares in the image plane"""
         
@@ -826,12 +653,13 @@ class imaging_tests(unittest.TestCase):
         # Build the data dictionary
         out = vis.build_sim_data(aa, vis.SOURCES, jd=2458962.16965)
         
-        # Build an image
-        img = utils.build_gridded_image(out)
-        
-        # CLEAN
-        deconv.lsq(aa, out, img, max_iter=2, verbose=False, plot=run_plotting_tests)
-        
+        with lsl.testing.SilentVerbose():
+            # Build an image
+            img = utils.build_gridded_image(out)
+            
+            # CLEAN
+            deconv.lsq(aa, out, img, max_iter=2, verbose=False, plot=run_plotting_tests)
+            
     @unittest.skipUnless(run_plotting_tests, "requires the 'matplotlib' module")
     def test_plotting(self):
         """Test drawing an image."""
@@ -915,8 +743,10 @@ class imaging_tests(unittest.TestCase):
         fig = plt.figure()
         ax = fig.gca()
         utils.plot_gridded_image(ax, img)
-        overlay.graticule_radec(ax, aa)
-        overlay.graticule_azalt(ax, aa)
+        with self.subTest(type='RA/Dec.'):
+            overlay.graticule_radec(ax, aa)
+        with self.subTest(type='az/alt'):
+            overlay.graticule_azalt(ax, aa)
         del fig
         
     def tearDown(self):
