@@ -9,7 +9,9 @@ if sys.version_info < (3,):
     range = xrange
     
 import os
+import numpy
 import unittest
+from datetime import timedelta
 
 from lsl.common.paths import DATA_BUILD
 from lsl.reader import tbw
@@ -21,7 +23,7 @@ from lsl.reader import errors
 from lsl.reader.base import FrameTimestamp
 
 
-__version__  = "0.8"
+__version__  = "0.9"
 __author__    = "Jayce Dowell"
 
 
@@ -131,6 +133,16 @@ class reader_tests(unittest.TestCase):
         self.assertAlmostEqual(t, FrameTimestamp(1587495779, 0.6), 6)
         self.assertAlmostEqual(t, 1587495779.6, 6)
         
+        t = t + timedelta(seconds=1)
+        self.assertEqual(t, FrameTimestamp(1587495780, 0.6))
+        self.assertAlmostEqual(t, FrameTimestamp(1587495780, 0.6), 6)
+        self.assertAlmostEqual(t, 1587495780.6, 6)
+        
+        t += timedelta(seconds=1, microseconds=400000)
+        self.assertEqual(t, FrameTimestamp(1587495782, 0.0))
+        self.assertAlmostEqual(t, FrameTimestamp(1587495782, 0.0), 6)
+        self.assertAlmostEqual(t, 1587495782.0, 6)
+        
     def test_timestamp_sub(self):
         """Test subtracting from a FrameTimestamp"""
         
@@ -154,6 +166,16 @@ class reader_tests(unittest.TestCase):
         self.assertAlmostEqual(t0, FrameTimestamp(1587495778, 0.0), 6)
         self.assertAlmostEqual(t0, 1587495778.0, 6)
         
+        t0 = t0 - timedelta(seconds=1)
+        self.assertEqual(t0, FrameTimestamp(1587495777, 0.0))
+        self.assertAlmostEqual(t0, FrameTimestamp(1587495777, 0.0), 6)
+        self.assertAlmostEqual(t0, 1587495777.0, 6)
+        
+        t0 -= timedelta(seconds=1, microseconds=500000)
+        self.assertEqual(t0, FrameTimestamp(1587495775, 0.5))
+        self.assertAlmostEqual(t0, FrameTimestamp(1587495775, 0.5), 6)
+        self.assertAlmostEqual(t0, 1587495775.5, 6)
+        
     def test_timestmp_cmp(self):
         """Test FrameTimestamp comparisons"""
         
@@ -259,26 +281,20 @@ class reader_tests(unittest.TestCase):
         
         # Multiplication
         frameT = frames[0] * 2.0
-        for i in range(800):
-            self.assertAlmostEqual(frameT.payload.data[i%2, i//2], 2*frames[0].payload.data[i%2, i//2], 2)
+        numpy.testing.assert_allclose(frameT.payload.data, 2*frames[0].payload.data)
         frameT *= 2.0
-        for i in range(800):
-            self.assertAlmostEqual(frameT.payload.data[i%2, i//2], 4*frames[0].payload.data[i%2, i//2], 2)
+        numpy.testing.assert_allclose(frameT.payload.data, 4*frames[0].payload.data)
         frameT = frames[0] * frames[1]
-        for i in range(800):
-            self.assertAlmostEqual(frameT.payload.data[i%2, i//2], frames[0].payload.data[i%2, i//2]*frames[1].payload.data[i%2, i//2], 2)
-            
+        numpy.testing.assert_allclose(frameT.payload.data, frames[0].payload.data*frames[1].payload.data)
+        
         # Addition
         frameA = frames[0] + 2.0
-        for i in range(800):
-            self.assertAlmostEqual(frameA.payload.data[i%2, i//2], 2+frames[0].payload.data[i%2, i//2], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, 2+frames[0].payload.data)
         frameA += 2.0
-        for i in range(800):
-            self.assertAlmostEqual(frameA.payload.data[i%2, i//2], 4+frames[0].payload.data[i%2, i//2], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, 4+frames[0].payload.data)
         frameA = frames[0] + frames[1]
-        for i in range(800):
-            self.assertAlmostEqual(frameA.payload.data[i%2, i//2], frames[0].payload.data[i%2, i//2]+frames[1].payload.data[i%2, i//2], 2)
-            
+        numpy.testing.assert_allclose(frameA.payload.data, frames[0].payload.data+frames[1].payload.data)
+        
     ### TBN ###
     
     def test_tbn_read(self):
@@ -385,25 +401,19 @@ class reader_tests(unittest.TestCase):
         
         # Multiplication
         frameT = frames[0] * 2.0
-        for i in range(512):
-            self.assertAlmostEqual(frameT.payload.data[i], 2*frames[0].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameT.payload.data, 2*frames[0].payload.data, atol=1e-6)
         frameT *= 2.0
-        for i in range(512):
-            self.assertAlmostEqual(frameT.payload.data[i], 4*frames[0].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameT.payload.data, 4*frames[0].payload.data, atol=1e-6)
         frameT = frames[0] * frames[1]
-        for i in range(512):
-            self.assertAlmostEqual(frameT.payload.data[i], frames[0].payload.data[i]*frames[1].payload.data[i], 2)
-            
+        numpy.testing.assert_allclose(frameT.payload.data, frames[0].payload.data*frames[1].payload.data, atol=1e-6)
+        
         # Addition
         frameA = frames[0] + 2.0
-        for i in range(512):
-            self.assertAlmostEqual(frameA.payload.data[i], 2+frames[0].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, 2+frames[0].payload.data, atol=1e-6)
         frameA += 2.0
-        for i in range(512):
-            self.assertAlmostEqual(frameA.payload.data[i], 4+frames[0].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, 4+frames[0].payload.data, atol=1e-6)
         frameA = frames[0] + frames[1]
-        for i in range(512):
-            self.assertAlmostEqual(frameA.payload.data[i], frames[0].payload.data[i]+frames[1].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, frames[0].payload.data+frames[1].payload.data, atol=1e-6)
             
     ### TBW/TBN Mix-up ###
     
@@ -538,25 +548,19 @@ class reader_tests(unittest.TestCase):
         
         # Multiplication
         frameT = frames[0] * 2.0
-        for i in range(4096):
-            self.assertAlmostEqual(frameT.payload.data[i], 2*frames[0].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameT.payload.data, 2*frames[0].payload.data, atol=1e-6)
         frameT *= 2.0
-        for i in range(4096):
-            self.assertAlmostEqual(frameT.payload.data[i], 4*frames[0].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameT.payload.data, 4*frames[0].payload.data, atol=1e-6)
         frameT = frames[0] * frames[1]
-        for i in range(4096):
-            self.assertAlmostEqual(frameT.payload.data[i], frames[0].payload.data[i]*frames[1].payload.data[i], 2)
-            
+        numpy.testing.assert_allclose(frameT.payload.data, frames[0].payload.data*frames[1].payload.data, atol=1e-6)
+        
         # Addition
         frameA = frames[0] + 2.0
-        for i in range(4096):
-            self.assertAlmostEqual(frameA.payload.data[i], 2+frames[0].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, 2+frames[0].payload.data, atol=1e-6)
         frameA += 2.0
-        for i in range(4096):
-            self.assertAlmostEqual(frameA.payload.data[i], 4+frames[0].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, 4+frames[0].payload.data, atol=1e-6)
         frameA = frames[0] + frames[1]
-        for i in range(4096):
-            self.assertAlmostEqual(frameA.payload.data[i], frames[0].payload.data[i]+frames[1].payload.data[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, frames[0].payload.data+frames[1].payload.data, atol=1e-6)
             
     ### DR Spectrometer ###
     
@@ -684,25 +688,19 @@ class reader_tests(unittest.TestCase):
         
         # Multiplication
         frameT = frames[0] * 2.0
-        for i in range(npts):
-            self.assertAlmostEqual(frameT.payload.XX0[i], 2*frames[0].payload.XX0[i], 2)
+        numpy.testing.assert_allclose(frameT.payload.XX0, 2*frames[0].payload.XX0, atol=1e-6)
         frameT *= 2.0
-        for i in range(npts):
-            self.assertAlmostEqual(frameT.payload.XX1[i], 4*frames[0].payload.XX1[i], 2)
+        numpy.testing.assert_allclose(frameT.payload.XX1, 4*frames[0].payload.XX1, atol=1e-6)
         frameT = frames[0] * frames[1]
-        for i in range(npts):
-            self.assertAlmostEqual(frameT.payload.YY0[i], frames[0].payload.YY0[i]*frames[1].payload.YY0[i], 2)
+        numpy.testing.assert_allclose(frameT.payload.YY0, frames[0].payload.YY0*frames[1].payload.YY0, atol=1e-6)
             
         # Addition
         frameA = frames[0] + 2.0
-        for i in range(npts):
-            self.assertAlmostEqual(frameA.payload.XX0[i], 2+frames[0].payload.XX0[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.XX0, 2+frames[0].payload.XX0, atol=1e-6)
         frameA += 2.0
-        for i in range(npts):
-            self.assertAlmostEqual(frameA.payload.XX1[i], 4+frames[0].payload.XX1[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.XX0, 4+frames[0].payload.XX0, atol=1e-6)
         frameA = frames[0] + frames[1]
-        for i in range(npts):
-            self.assertAlmostEqual(frameA.payload.YY0[i], frames[0].payload.YY0[i]+frames[1].payload.YY0[i], 2)
+        numpy.testing.assert_allclose(frameA.payload.YY0, frames[0].payload.YY0+frames[1].payload.YY0, atol=1e-6)
             
     ### VDIF ###
     
@@ -826,31 +824,19 @@ class reader_tests(unittest.TestCase):
         
         # Multiplication
         frameT = frames[0] * 2.0
-        for i in range(nchan):
-            for j in range(nSamples):
-                self.assertAlmostEqual(frameT.payload.data[i,j], 2*frames[0].payload.data[i,j], 2)
+        numpy.testing.assert_allclose(frameT.payload.data, 2*frames[0].payload.data, atol=1e-6)
         frameT *= 2.0
-        for i in range(nchan):
-            for j in range(nSamples):
-                self.assertAlmostEqual(frameT.payload.data[i,j], 4*frames[0].payload.data[i,j], 2)
+        numpy.testing.assert_allclose(frameT.payload.data, 4*frames[0].payload.data, atol=1e-6)
         frameT = frames[0] * frames[1]
-        for i in range(nchan):
-            for j in range(nSamples):
-                self.assertAlmostEqual(frameT.payload.data[i,j], frames[0].payload.data[i,j]*frames[1].payload.data[i,j], 2)
-            
+        numpy.testing.assert_allclose(frameT.payload.data, frames[0].payload.data*frames[1].payload.data, atol=1e-6)
+        
         # Addition
         frameA = frames[0] + 2.0
-        for i in range(nchan):
-            for j in range(nSamples):
-                self.assertAlmostEqual(frameA.payload.data[i,j], 2+frames[0].payload.data[i,j], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, 2+frames[0].payload.data, atol=1e-6)
         frameA += 2.0
-        for i in range(nchan):
-            for j in range(nSamples):
-                self.assertAlmostEqual(frameA.payload.data[i,j], 4+frames[0].payload.data[i,j], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, 4+frames[0].payload.data, atol=1e-6)
         frameA = frames[0] + frames[1]
-        for i in range(nchan):
-            for j in range(nSamples):
-                self.assertAlmostEqual(frameA.payload.data[i,j], frames[0].payload.data[i,j]+frames[1].payload.data[i,j], 2)
+        numpy.testing.assert_allclose(frameA.payload.data, frames[0].payload.data+frames[1].payload.data, atol=1e-6)
 
 
 class reader_test_suite(unittest.TestSuite):
